#[non_exhaustive]pub enum FileProtocol {
Unspecified,
NfsV3,
NfsV41,
UnknownValue(UnknownValue),
}Expand description
File access protocol.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
FILE_PROTOCOL_UNSPECIFIED serves a “not set” default value when a FileProtocol is a separate field in a message.
NfsV3
NFS 3.0.
NfsV41
NFS 4.1.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using FileProtocol::value or FileProtocol::name.
Implementations