#[non_exhaustive]pub struct PerformanceConfig {
pub mode: Option<Mode>,
/* private fields */
}Expand description
Used for setting the performance configuration. If the user doesn’t specify PerformanceConfig, automatically provision the default performance settings as described in https://cloud.google.com/filestore/docs/performance. Larger instances will be linearly set to more IOPS. If the instance’s capacity is increased or decreased, its performance will be automatically adjusted upwards or downwards accordingly (respectively).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mode: Option<Mode>Implementations
Sourceimpl PerformanceConfig
impl PerformanceConfig
Sourcepub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
pub fn set_mode<T: Into<Option<Mode>>>(self, v: T) -> Self
Sets the value of mode.
Note that all the setters affecting mode are mutually
exclusive.
Example
use google_cloud_filestore_v1::model::instance::IOPSPerTB;
let x = PerformanceConfig::new().set_mode(Some(
google_cloud_filestore_v1::model::instance::performance_config::Mode::IopsPerTb(IOPSPerTB::default().into())));Sourcepub fn iops_per_tb(&self) -> Option<&Box<IOPSPerTB>>
pub fn iops_per_tb(&self) -> Option<&Box<IOPSPerTB>>
The value of mode
if it holds a IopsPerTb, None if the field is not set or
holds a different branch.
Sourcepub fn set_iops_per_tb<T: Into<Box<IOPSPerTB>>>(self, v: T) -> Self
pub fn set_iops_per_tb<T: Into<Box<IOPSPerTB>>>(self, v: T) -> Self
Sets the value of mode
to hold a IopsPerTb.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_filestore_v1::model::instance::IOPSPerTB;
let x = PerformanceConfig::new().set_iops_per_tb(IOPSPerTB::default()/* use setters */);
assert!(x.iops_per_tb().is_some());
assert!(x.fixed_iops().is_none());Sourcepub fn fixed_iops(&self) -> Option<&Box<FixedIOPS>>
pub fn fixed_iops(&self) -> Option<&Box<FixedIOPS>>
The value of mode
if it holds a FixedIops, None if the field is not set or
holds a different branch.
Sourcepub fn set_fixed_iops<T: Into<Box<FixedIOPS>>>(self, v: T) -> Self
pub fn set_fixed_iops<T: Into<Box<FixedIOPS>>>(self, v: T) -> Self
Sets the value of mode
to hold a FixedIops.
Note that all the setters affecting mode are
mutually exclusive.
Example
use google_cloud_filestore_v1::model::instance::FixedIOPS;
let x = PerformanceConfig::new().set_fixed_iops(FixedIOPS::default()/* use setters */);
assert!(x.fixed_iops().is_some());
assert!(x.iops_per_tb().is_none());Trait Implementations
Sourceimpl Clone for PerformanceConfig
impl Clone for PerformanceConfig
Sourcefn clone(&self) -> PerformanceConfig
fn clone(&self) -> PerformanceConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more