#[non_exhaustive]pub struct RestoreInstanceRequest {
pub name: String,
pub file_share: String,
pub source: Option<Source>,
/* private fields */
}Expand description
RestoreInstanceRequest restores an existing instance’s file share from a backup.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the instance, in the format
projects/{project_number}/locations/{location_id}/instances/{instance_id}.
Required. Name of the file share in the Filestore instance that the backup is being restored to.
source: Option<Source>Implementations
Sourceimpl RestoreInstanceRequest
impl RestoreInstanceRequest
Sets the value of file_share.
Example
ⓘ
let x = RestoreInstanceRequest::new().set_file_share("example");Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sourcepub fn source_backup(&self) -> Option<&String>
pub fn source_backup(&self) -> Option<&String>
The value of source
if it holds a SourceBackup, None if the field is not set or
holds a different branch.